@@ -52,6 +52,9 @@ class WordRules {
 		/** Only applicable for functionalTerms. The string value of the functionalTerm's type attribute*/
 		private final String functionalGroupType;
 		
+		/** Only applicable for functionalTerms. The string value of the functionalTerm's subType attribute*/
+		private final String functionalGroupSubType;
+		
 		/** The value of the type attribute of the last group element in the word e.g. maybe aminoAcid*/
 		private final String endsWithGroupType;
 		
@@ -68,41 +71,49 @@ class WordRules {
 			EndsWithGroup endsWithGroup = null;
 			Pattern endsWithPattern = null;
 			String functionalGroupType = null;
+			String functionalGroupSubType = null;
 			String endsWithGroupType = null;
 			String endsWithGroupSubType = null;
 			for (int i = 0, l = reader.getAttributeCount(); i < l; i++) {
-				String atrName = reader.getAttributeLocalName(i);
 				String atrValue = reader.getAttributeValue(i);
-				if (atrName.equals("type")){
+				switch (reader.getAttributeLocalName(i)) {
+				case "type":
 					type = WordType.valueOf(atrValue);
-				}
-				else if (atrName.equals("value")){
+					break;
+				case "value":
 					value = atrValue;
-				}
-				else if (atrName.equals("functionalGroupType")){
+					break;
+				case "functionalGroupType":
 					functionalGroupType = atrValue;
-				}
-				else if (atrName.equals("endsWith")){
+					break;
+				case "functionalGroupSubType":
+					functionalGroupSubType = atrValue;
+					break;
+				case "endsWith":
 					endsWithGroup = EndsWithGroup.valueOf(atrValue);
-				}
-				else if (atrName.equals("endsWithRegex")){
+					break;
+				case "endsWithRegex":
 					endsWithPattern = Pattern.compile(atrValue +"$", Pattern.CASE_INSENSITIVE);
-				}
-				else if (atrName.equals("endsWithGroupType")){
+					break;
+				case "endsWithGroupType":
 					endsWithGroupType = atrValue;
-				}
-				else if (atrName.equals("endsWithGroupSubType")){
+					break;
+				case "endsWithGroupSubType":
 					endsWithGroupSubType = atrValue;
+					break;
+				default:
+					break;
 				}
 			}
 			if (type == null) {
-				throw new RuntimeException("Malformed wordRules");
+				throw new RuntimeException("Malformed wordRule, no type specified");
 			}
 			this.type = type;
 			this.endsWithGroup = endsWithGroup;
 			this.endsWithPattern = endsWithPattern;
 			this.value = value;
 			this.functionalGroupType = functionalGroupType;
+			this.functionalGroupSubType = functionalGroupSubType;
 			this.endsWithGroupType = endsWithGroupType;
 			this.endsWithGroupSubType = endsWithGroupSubType;
 		}
@@ -126,6 +137,10 @@ class WordRules {
 		String getFunctionalGroupType() {
 			return functionalGroupType;
 		}
+		
+		String getFunctionalGroupSubType() {
+			return functionalGroupSubType;
+		}
 
 		String getEndsWithGroupType() {
 			return endsWithGroupType;
@@ -164,7 +179,7 @@ class WordRules {
 		 * @throws XMLStreamException 
 		 */
 		WordRuleDescription(XMLStreamReader reader) throws XMLStreamException {
-			List<WordDescription> wordDescriptions = new ArrayList<WordDescription>();
+			List<WordDescription> wordDescriptions = new ArrayList<>();
 			ruleName = WordRule.valueOf(reader.getAttributeValue(null, "name"));
 			ruleType = WordType.valueOf(reader.getAttributeValue(null,"type"));
 			while (reader.hasNext()) {
@@ -190,7 +205,7 @@ class WordRules {
 	 * @throws IOException 
 	 */
 	WordRules(ResourceGetter resourceGetter) throws IOException {
-		List<WordRuleDescription> wordRuleList = new ArrayList<WordRuleDescription>();
+		List<WordRuleDescription> wordRuleList = new ArrayList<>();
 		XMLStreamReader reader = resourceGetter.getXMLStreamReader("wordRules.xml");
 		try {
 			while (reader.hasNext()) {
@@ -264,7 +279,8 @@ class WordRules {
 						}
 
 						String functionalGroupTypePredicate = wd.getFunctionalGroupType();
-						if (functionalGroupTypePredicate != null) {
+						String functionalGroupSubTypePredicate = wd.getFunctionalGroupSubType();
+						if (functionalGroupTypePredicate != null || functionalGroupSubTypePredicate != null) {
 							if (!WordType.functionalTerm.toString().equals(wordEl.getAttributeValue(TYPE_ATR))){
 								continue wordRuleLoop;
 							}
@@ -278,7 +294,10 @@ class WordRules {
 									throw new ParsingException("OPSIN Bug: Cannot find the functional element in a functionalTerm");
 								}
 							}
-							if (!functionalGroupTypePredicate.equals(lastEl.getAttributeValue(TYPE_ATR))) {
+							if (functionalGroupTypePredicate != null && !functionalGroupTypePredicate.equals(lastEl.getAttributeValue(TYPE_ATR))) {
+								continue wordRuleLoop;
+							}
+							if (functionalGroupSubTypePredicate != null && !functionalGroupSubTypePredicate.equals(lastEl.getAttributeValue(SUBTYPE_ATR))) {
 								continue wordRuleLoop;
 							}
 						}
@@ -468,7 +487,7 @@ class WordRules {
 						break;
 					}
 
-					List<String> wordValues = new ArrayList<String>();
+					List<String> wordValues = new ArrayList<>();
 					Element parentEl = wordEls.get(i).getParent();
 					int indexToInsertAt = parentEl.indexOf(wordEls.get(i));
 					for (int j = 0; j < wordsInWordRule; j++) {
@@ -502,7 +521,7 @@ class WordRules {
 					}
 				}
 			}
-			else if (WordType.functionalTerm.toString().equals(firstWord.getAttributeValue(TYPE_ATR)) &&  firstWord.getAttributeValue(VALUE_ATR).toLowerCase(Locale.ROOT).equals("salt")) {
+			else if (WordType.functionalTerm.toString().equals(firstWord.getAttributeValue(TYPE_ATR)) && firstWord.getAttributeValue(VALUE_ATR).equalsIgnoreCase("salt")) {
 				wordEls.remove(indexOfFirstWord);
 				firstWord.detach();
 				if (moleculeEl.getAttribute(ISSALT_ATR) == null) {
@@ -510,9 +529,16 @@ class WordRules {
 				}
 				return true;
 			}
-			if (allowRadicals && wordEls.size() == 1 && indexOfFirstWord == 0 && firstWord.getName().equals(WORD_EL) && WordType.substituent.toString().equals(firstWord.getAttributeValue(TYPE_ATR))){
-				//name is all one substituent, make this a substituent and finish
-				applySubstituentWordRule(wordEls, indexOfFirstWord, firstWord);
+			
+			if (wordEls.size() == 1 && indexOfFirstWord == 0 && firstWord.getName().equals(WORD_EL) && WordType.substituent.toString().equals(firstWord.getAttributeValue(TYPE_ATR))) {
+				if (firstWord.getAttributeValue(VALUE_ATR).equalsIgnoreCase("dihydrogen")) {
+					convertToDihydrogenMolecule(firstWord);
+					return true;
+				}				
+				if (allowRadicals) {
+					//name is all one substituent, make this a substituent and finish
+					applySubstituentWordRule(wordEls, indexOfFirstWord, firstWord);
+				}
 			}
 			return false;
 		}
@@ -620,7 +646,6 @@ class WordRules {
 			wordEls.set(indexOfFirstWord, wordRuleEl);
 			parentEl.insertChild(wordRuleEl, indexToInsertAt);
 		}
-		
 
 		private void applySubstituentWordRule(List<Element> wordEls, int indexOfFirstWord, Element firstWord) {
 			Element parentEl = firstWord.getParent();
@@ -687,6 +712,20 @@ class WordRules {
 			return functionalGroup;
 		}
 		
+		private void convertToDihydrogenMolecule(Element word) {
+			word.getAttribute(TYPE_ATR).setValue(WordType.full.toString());
+			for (int i = word.getChildCount() - 1; i >=0; i--) {
+				word.removeChild(i);
+			}
+			Element root = new GroupingEl(ROOT_EL);
+			Element group = new TokenEl(GROUP_EL);
+			group.addAttribute(TYPE_ATR, SIMPLEGROUP_TYPE_VAL);
+			group.addAttribute(SUBTYPE_ATR, SIMPLEGROUP_SUBTYPE_VAL);
+			group.addAttribute(VALUE_ATR, "[H][H]");
+			group.setValue("dihydrogen");
+			root.addChild(group);
+			word.addChild(root);
+		}
 
 		/**
 		 * Sets the SMILES of the oxide group to be something like [O-2]
